TimeEwma

Struct TimeEwma 

pub struct TimeEwma { /* private fields */ }
Continuous-Time Exponentially Weighted Moving Average.

This is used to average values that are observed at irregular intervals but have a fixed value between the observations, AKA a piecewise-constant signal sampled at change points. Instead of an “alpha” parameter, this uses a “half-life” parameter which is the time it takes for the average to decay to half of its value, measured in seconds.

Implementations

Source

impl TimeEwma

pub const fn new(half_life_seconds: f64) -> Self

pub fn average(&self) -> Option<f64>

pub fn update(&mut self, point: f64, reference: Instant) -> f64

Update the current average and return it for convenience. Note that this average will “lag” the current observation because the new average is based on the previous point and the duration during which it was held constant. If the reference time is before the previous update, the update is ignored and the previous average is returned.